@@ -4,7 +4,7 @@ use LWP::Simple;
 use JSON::Parse;
 use XML::Feed;
 
-our $VERSION = '0.38'; # This is the overall version for the entire
+our $VERSION = '0.40'; # This is the overall version for the entire
 # package, so should probably be updated even when the other modules are
 # touched.
 
@@ -32,7 +32,7 @@ sub new {
         $api_url = 'https://sourceforge.net/api';
     }
 
-    $self = bless(
+    my $self = bless(
         {
             api_url => $api_url,
             api     => $api,
@@ -73,6 +73,7 @@ sub call {
     # https://sourceforge.net/p/forge/documentation/Download%20Stats%20API/
     if ( $self->{api} eq 'download' ) {
 
+
         # TODO: Default start date, end date (last 7 days, perhaps?)
 
         # TODO: API allows specification of subdirs of the files
